pub struct CounterStyleRule {
name: CustomIdent,
generation: Wrapping<u32>,
descriptors: Descriptors,
pub source_location: SourceLocation,
}Expand description
A @counter-style rule
Fields
name: CustomIdentgeneration: Wrapping<u32>descriptors: Descriptorssource_location: SourceLocationThe parser location of the @counter-style rule.
Implementations
Sourceimpl CounterStyleRule
impl CounterStyleRule
fn empty(name: CustomIdent, source_location: SourceLocation) -> Self
Sourcepub fn descriptors(&self) -> &Descriptors
pub fn descriptors(&self) -> &Descriptors
Expose the descriptors as read-only, since we rely on updating our generation when they change, and some setters need extra validation.
Sourcepub fn set_descriptor<'i>(
&mut self,
id: DescriptorId,
context: &ParserContext<'_>,
input: &mut Parser<'i, '_>,
) -> Result<bool, ParseError<'i>>
pub fn set_descriptor<'i>( &mut self, id: DescriptorId, context: &ParserContext<'_>, input: &mut Parser<'i, '_>, ) -> Result<bool, ParseError<'i>>
Set a descriptor, with the relevant validation. returns whether the descriptor changed.
Sourcefn check_system(&self, value: &System) -> bool
fn check_system(&self, value: &System) -> bool
Check that the system is effectively not changed. Only params of system descriptor is changeable.
fn check_symbols(&self, value: &Symbols) -> bool
Sourcepub fn name(&self) -> &CustomIdent
pub fn name(&self) -> &CustomIdent
Get the name of the counter style rule.
Sourcepub fn set_name(&mut self, name: CustomIdent)
pub fn set_name(&mut self, name: CustomIdent)
Set the name of the counter style rule. Caller must ensure that the name is valid.
Sourcepub fn generation(&self) -> u32
pub fn generation(&self) -> u32
Get the current generation of the counter style rule.
Sourcepub fn resolved_system(&self) -> &System
pub fn resolved_system(&self) -> &System
Get the system of this counter style rule, default to
symbolic if not specified.